@@ -9,8 +9,8 @@
  */
 
 .pragma library
-.import QtQuick 2.9 as Quick
-.import QtQml 2.2 as Qml
+.import QtQuick 2.12 as Quick
+.import QtQml 2.12 as Qml
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
@@ -22,11 +22,7 @@ var currentLevelConfig
 var dataset
 var items
 var daySelected = 1
-var monthSelected = 2
-var yearSelected = 2018
 var dayOfWeekSelected
-var minRange //sum of min. visible month and year on calendar for navigation bar next/prev button visibility.
-var maxRange //sum of max. visible month and year on calendar for navigation bar next/prev button visibility.
 var correctAnswer
 var mode
 
@@ -43,7 +39,6 @@ function start(items_, dataset_) {
 }
 
 function stop() {
-    items.questionDelay.stop();
 }
 
 function initLevel() {
@@ -70,16 +65,14 @@ function previousLevel() {
 
 // Configure calendar properties for every level.
 function setCalendarConfigurations() {
-    minRange = Number(currentLevelConfig["minimumDate"].slice(5,7)) + Number(currentLevelConfig["minimumDate"].slice(0,4)) - 1;
-    maxRange = Number(currentLevelConfig["maximumDate"].slice(5,7)) + Number(currentLevelConfig["maximumDate"].slice(0,4)) - 1;
     mode = currentLevelConfig["mode"]
     items.calendar.navigationBarVisible = currentLevelConfig["navigationBarVisible"]
-    items.calendar.minimumDate = currentLevelConfig["minimumDate"]
-    items.calendar.maximumDate = currentLevelConfig["maximumDate"]
-    items.calendar.visibleYear = currentLevelConfig["visibleYear"]
-    yearSelected = currentLevelConfig["visibleYear"]
-    items.calendar.visibleMonth = currentLevelConfig["visibleMonth"]
-    monthSelected = currentLevelConfig["visibleMonth"]
+    items.calendar.selectedDay = 1;
+    items.calendar.minimumDate = new Date(currentLevelConfig["minimumDate"])
+    items.calendar.minimumDate.setHours(0);
+    items.calendar.maximumDate = new Date(currentLevelConfig["maximumDate"])
+    items.calendar.maximumDate.setHours(0);
+    items.calendar.currentDate = new Date(currentLevelConfig["visibleYear"], currentLevelConfig["visibleMonth"], items.calendar.selectedDay)
     items.answerChoices.visible = (mode === "findDayOfWeek") ? true : false
     items.okButton.visible = !items.answerChoices.visible
     currentDataSet = dataset[currentLevel][1]
@@ -126,10 +119,9 @@ function checkAnswer() {
     }
     // For levels having questions based on dayOfWeek, month and year.
     else if(mode !== "findDayOfWeek") {
-        if(monthSelected === correctAnswer["month"] && daySelected === correctAnswer["day"] && yearSelected === correctAnswer["year"]) {
+        if(items.calendar.currentDate.getMonth() === correctAnswer["month"] && daySelected === correctAnswer["day"] && items.calendar.currentDate.getFullYear() === correctAnswer["year"]) {
             isCorrectAnswer = true
         }
     }
     updateScore(isCorrectAnswer)
 }
-
