@@ -145,7 +145,7 @@ class ActivityInfo : public QObject
 
 public:
     /// @cond INTERNAL_DOCS
-    explicit ActivityInfo(QObject *parent = 0);
+    explicit ActivityInfo(QObject *parent = nullptr);
 
     QString name() const;
     void setName(const QString &);
@@ -192,7 +192,7 @@ public:
     void addDataset(const QString &name, Dataset *dataset);
     Q_INVOKABLE Dataset *getDataset(const QString &name) const;
 
-signals:
+Q_SIGNALS:
     void nameChanged();
     void sectionChanged();
     void difficultyChanged();
