@@ -18,7 +18,6 @@
 #include <QMutex>
 #include <QString>
 #include <QUrl>
-#include <QVariant>
 #include <QQmlEngine>
 #include <QJSEngine>
 
@@ -90,7 +89,7 @@ private:
         bool downloadFinished;
         int downloadResult;
         DownloadJob(const QUrl &u = QUrl()) :
-            url(u), file(), reply(0),
+            url(u), file(), reply(nullptr),
             queue(QList<QUrl>()),
             bytesReceived(0),
             bytesTotal(0),
@@ -142,7 +141,7 @@ private:
      *             - /usr/local/share/KDE/gcompris-qt
      *             - /usr/share/KDE/gcompris-qt
      */
-    QStringList getSystemResourcePaths() const;
+    const QStringList getSystemResourcePaths() const;
     QString getResourceRootForFilename(const QString &filename) const;
     QString getFilenameForUrl(const QUrl &url) const;
     QUrl getUrlForFilename(const QString &filename) const;
@@ -193,14 +192,14 @@ private:
     QStringList getLocalResources();
 #endif
 
-private slots:
+private Q_SLOTS:
 
     /** Handle a finished download.
      *
      * Called whenever a single download (sub-job) has finished. Responsible
      * for iterating over possibly remaining sub-jobs of our DownloadJob.
      */
-    void downloadFinished();
+    void finishDownload();
     void downloadReadyRead();
     void handleError(QNetworkReply::NetworkError code);
 
@@ -275,7 +274,7 @@ public:
      */
     Q_INVOKABLE bool registerResource(const QString &filename);
 
-public slots:
+public Q_SLOTS:
 
     /** Emitted when a download in progressing.
      *
@@ -335,7 +334,7 @@ public slots:
     Q_INVOKABLE void registerLocalResources();
 #endif
 
-signals:
+Q_SIGNALS:
 
     /** Emitted when a download error occurs.
      *
